Timeflux OpenBCI plugin
=======================

This plugin provides a unified interface for all `OpenBCI <https://openbci.com>`__ boards.

Installation
------------

First, make sure that `Timeflux <https://github.com/timeflux/timeflux>`__ is installed.

You can then install this plugin in the `timeflux` environment:

::

    $ conda activate timeflux
    $ pip install timeflux_openbci
